@@ -25,7 +25,7 @@ Usage::
     list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
     ```
 """
-from mypy_boto3_batch.client import BatchClient, BatchClient as Client
+from mypy_boto3_batch.client import BatchClient as Client, BatchClient
 from mypy_boto3_batch.paginator import (
     DescribeComputeEnvironmentsPaginator,
     DescribeJobDefinitionsPaginator,
